@@ -27,6 +27,7 @@ from pysisu.latest_analysis_result import to_table
 from pysisu.proto.sisu.v1.api import (
     AnalysesListResponse,
     AnalysisRunResultsResponse,
+    CreateDataSetRequestDataset,
     DataSetsResponse,
     DataSourceListResponse,
     DuplicateAnalysisResponse,
@@ -269,6 +270,17 @@ class PySisu:
             self._call_sisu_api(url_path, request_method="GET")
         )
 
+    def create_dataset(
+        self, data_source_id: int, body: CreateDataSetRequestDataset
+    ) -> GetSegmentDataResponse:
+        path = [f"api/v1/data_sources/{data_source_id}/datasets"]
+        url_path = build_url(self._url, pathjoin(*path), {})
+        return GetSegmentDataResponse().from_dict(
+            self._call_sisu_api(
+                url_path, request_method="POST", json=body.to_json()
+            )
+        )
+
     def get_projects(self) -> GetProjectsListResponseListProjectResponse:
         path = ["api/v1/projects"]
         url_path = build_url(self._url, pathjoin(*path), {})
